summaryrefslogtreecommitdiffstats
path: root/khtml/khtml_caret_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/khtml_caret_p.h')
-rw-r--r--khtml/khtml_caret_p.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/khtml/khtml_caret_p.h b/khtml/khtml_caret_p.h
index 9524f2df7..a5c4bf60d 100644
--- a/khtml/khtml_caret_p.h
+++ b/khtml/khtml_caret_p.h
@@ -1034,7 +1034,7 @@ public:
*/
int chr() const { return _char; }
/** returns the current character as a unicode symbol, substituting
* a blank for a non-text node.
*/
TQChar operator *() const { return TQChar(_char >= 0 ? _char : ' '); }
@@ -1089,7 +1089,7 @@ protected:
CaretBox *box = *copy;
InlineBox *b = box->inlineBox();
if (b && !box->isOutside() && b->isInlineTextBox())
- _char = static_cast<RenderText *>(b->object())->str->s[b->minOffset()].unicode();
+ _char = static_cast<RenderText *>(b->object())->str->s[b->minOffset()].tqunicode();
else
_char = -1;
}
@@ -1034,7 +1034,7 @@ public:
*/
int chr() const { return _char; }
- /** returns the current character as a unicode symbol, substituting
+ /** returns the current character as a tqunicode symbol, substituting
* a blank for a non-text node.
*/